
/*
 * The Real SoundTracker - error handling functions
 *
 * Copyright (C) 1999-2019 Michael Krause
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <string.h>
#include <unistd.h>
#include <errno.h>

#include "audio.h"

static void
error_error_common(int level,
    const char* text)
{
    // This uses the mixer backpipe (see decls in audio.h) to collect
    // all errors and warnings in one central place. Decls from
    // audio.h should probably be put into a more general place.
    int l = strlen(text);
    extern int pipeb[2];

    if (write(pipeb[1], &level, sizeof(level)) != sizeof(level) || write(pipeb[1], &l, sizeof(l)) != sizeof(l) || write(pipeb[1], text, l + 1) != l + 1) {
        perror("Audio thread: write()");
    }
}

void error_error(const char* text)
{
    error_error_common(AUDIO_BACKPIPE_ERROR_MESSAGE, text);
}

void error_warning(const char* text)
{
    error_error_common(AUDIO_BACKPIPE_WARNING_MESSAGE, text);
}

void error_errno(const char *text)
{
    const int level = AUDIO_BACKPIPE_ERRNO_MESSAGE;
    int l = strlen(text), e = errno;
    extern int pipeb[2];

    if (write(pipeb[1], &level, sizeof(int)) != sizeof(int) ||
        write(pipeb[1], &e, sizeof(e)) != sizeof(e) ||
        write(pipeb[1], &l, sizeof(l)) != sizeof(l) ||
        write(pipeb[1], text, l + 1) != l + 1)
        perror("Audio thread: write()");
}
